Module: MD4C
- Defined in:
- lib/md4c.rb,
lib/md4c/version.rb,
sig/md4c.rbs,
ext/md4c/rb_md4c.c
Overview
-- Copyright (C) 2026 gemmaro
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program. If not, see https://www.gnu.org/licenses/. ++
Defined Under Namespace
Modules: EqualByContent Classes: Anchor, CodeBlock, CodeText, Entity, Error, HTMLText, HardBreak, Heading, Image, LaTeXMathText, ListItem, NormalText, NullChar, OrderedList, Parser, SoftBreak, Table, TableData, TableHeader, UnorderedList, WikiLink
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
Class Method Details
.markdown_to_html {|arg0| ... } ⇒ void
This method returns an undefined value.
642 |
# File 'ext/md4c/rb_md4c.c', line 642
def self.markdown_to_html: (input: String) { (text_node) -> void } -> void
|